# -*- coding: utf-8 -*-
from __future__ import print_function, unicode_literals

import sys

from django.conf import settings
from django.core.exceptions import MiddlewareNotUsed
from django.http import Http404

pudb = None  # Silence pyflakes


def err_print(*args, **kwargs):
    print('!! ERROR:', *args, file=sys.stderr, **kwargs)


class PudbMiddleware(object):
    def __init__(self, get_response=None):
        # django >= 1.10
        if get_response:
            self.get_response = get_response

        if not getattr(settings, 'DEBUG', False):
            raise MiddlewareNotUsed

        import sys
        if '--nothreading' not in sys.argv:
            err_print(
                'PudbMiddleware: Threading not (yet) supported, unloading myself.'
            )
            err_print('Please run with runserver --nothreading.')
            raise MiddlewareNotUsed

        try:
            global pudb
            import pudb
            assert pudb  # Silence pyflakes
        except ImportError:
            err_print('PudbMiddleware: Could not import pudb, unloading myself.')
            raise MiddlewareNotUsed

        print('PudbMiddleware: DEBUG enabled and pudb found, intercepting all uncaught exceptions.')

    def __call__(self, request):
        response = self.get_response(request)
        return response

    def process_exception(self, request, exception):
        if isinstance(exception, Http404):
            return
        print('PudbMiddleware: activating on "{0}"'.format(repr(exception)))
        pudb.post_mortem()



#! /usr/bin/env python
# -*- coding: utf-8 -*-
from __future__ import print_function, unicode_literals

import os

from setuptools import setup


def read(*paths):
    """Build a file path from *paths* and return the contents."""
    with open(os.path.join(*paths), 'r') as f:
        return f.read()


setup(
    name='django-pudb3',
    version='0.2.0',
    description='Django middleware to view exceptions in PuDB.',
    long_description=read('README.md'),
    long_description_content_type='text/markdown',
    url='https://github.com/hielkewalinga/django-pudb3/',
    license='MIT',
    author='Hielke Walinga',
    author_email='hielkewaligna@gmail.com',
    py_modules=['django_pudb'],
    include_package_data=True,
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
